#[non_exhaustive]pub enum UAttributesError {
ValidationError(String),
ParsingError(String),
}Expand description
Errors produced when building or validating UAttributes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ValidationError(String)
The attributes violate a validation rule for their message type.
ParsingError(String)
The attributes could not be parsed from their serialized form.
Implementations
Sourceimpl UAttributesError
impl UAttributesError
Sourcepub fn validation_error<T>(message: T) -> UAttributesError
pub fn validation_error<T>(message: T) -> UAttributesError
Creates a validation error with the given message.
Sourcepub fn parsing_error<T>(message: T) -> UAttributesError
pub fn parsing_error<T>(message: T) -> UAttributesError
Creates a parsing error with the given message.