Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Function verify_uninit_tx_buffer_payload_layout

pub fn verify_uninit_tx_buffer_payload_layout(
    buffer: &mut impl UUninitTxBuffer,
    payload_len: usize,
    alignment: usize,
) -> Result<(), UStatus>
Verifies the visible uninitialized transmit payload layout exposed by a loan.

Errors

Returns an error if the requested layout is invalid or the exposed payload range does not match it.