pub struct MockLocalUriProvider { /* private fields */ }Expand description
A factory for URIs representing this uEntity’s resources.
Implementations may use arbitrary mechanisms to determine the information that is necessary for creating URIs, e.g. environment variables, configuration files etc. Role: standalone utility answering “what is my address?”; implemented per uEntity, consumed by the roles — see the trait map.
Implementations
Sourceimpl MockLocalUriProvider
impl MockLocalUriProvider
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockLocalUriProvider
impl MockLocalUriProvider
Create an Expectation for mocking the get_authority method
Sourcepub fn expect_get_resource_uri(&mut self) -> &mut Expectation
pub fn expect_get_resource_uri(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_resource_uri method
Sourcepub fn expect_get_source_uri(&mut self) -> &mut Expectation
pub fn expect_get_source_uri(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_source_uri method