pub struct StaticUriProvider { /* private fields */ }Expand description
A URI provider that is statically configured with the uEntity’s authority, entity ID and version.
Implementations
Sourceimpl StaticUriProvider
impl StaticUriProvider
Sourcepub fn new(
authority: impl Into<String>,
entity_id: u32,
major_version: u8,
) -> Result<Self, UUriError>
pub fn new( authority: impl Into<String>, entity_id: u32, major_version: u8, ) -> Result<Self, UUriError>
Creates a new URI provider from static information.
Arguments
authority- The uEntity’s authority name.entity_id- The entity identifier.major_version- The uEntity’s major version.
Examples
use up_rust::{LocalUriProvider, StaticUriProvider};
let provider = StaticUriProvider::new("my-vehicle", 0x4210, 0x05).unwrap();
assert_eq!(provider.get_authority(), "my-vehicle");Trait Implementations
Sourceimpl Debug for StaticUriProvider
impl Debug for StaticUriProvider
Sourceimpl From<&UUri> for StaticUriProvider
impl From<&UUri> for StaticUriProvider
Sourcefn from(source_uri: &UUri) -> Self
fn from(source_uri: &UUri) -> Self
Creates a URI provider from a UUri.
Arguments
source_uri- The UUri to take the entity’s authority, entity ID and version information from. The UUri’s resource ID is ignored.
Examples
use up_rust::{LocalUriProvider, StaticUriProvider, UUri};
let source_uri = UUri::try_from("//my-vehicle/4210/5/1000").unwrap();
let provider = StaticUriProvider::from(&source_uri);
assert_eq!(provider.get_authority(), "my-vehicle");
assert_eq!(provider.get_source_uri(), source_uri.clone_with_resource_id(0x0000));Sourceimpl From<UUri> for StaticUriProvider
impl From<UUri> for StaticUriProvider
Sourceimpl LocalUriProvider for StaticUriProvider
impl LocalUriProvider for StaticUriProvider
Gets the authority used for URIs representing this uEntity’s resources.
Sourcefn get_resource_uri(&self, resource_id: u16) -> UUri
fn get_resource_uri(&self, resource_id: u16) -> UUri
Gets a URI that represents a given resource of this uEntity.
Sourcefn get_source_uri(&self) -> UUri
fn get_source_uri(&self) -> UUri
Gets the URI that represents the resource that this uEntity expects
RPC responses and notifications to be sent to.