Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct UUri

#[repr(C)]
pub struct UUri { /* private fields */ }
A URI that represents a uProtocol resource identifier.

Implementations

Source

impl UUri

pub fn to_uri(&self, include_scheme: bool) -> String

Serializes this UUri to a URI string.

Arguments
  • include_scheme - Indicates whether to include the uProtocol scheme (up) in the URI.
Returns

The URI as defined by the uProtocol Specification.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("vin.vehicles", 0x0000_800A, 0x02, 0x1a50).unwrap();
let uri_string = uuri.to_uri(true);
assert_eq!(uri_string, "up://vin.vehicles/800A/2/1A50");
pub fn try_from_parts( authority: &str, entity_id: u32, entity_version: u8, resource_id: u16, ) -> Result<Self, UUriError>

Creates a new UUri from its parts.

Errors

Returns a UUriError::ValidationError if the authority does not comply with the UUri specification.

Examples
use up_rust::UUri;

assert!(UUri::try_from_parts("vin", 0x0000_5a6b, 0x01, 0x0001).is_ok());
pub fn any() -> Self

Gets a pattern URI that matches any given candidate URI.

pub fn any_with_resource_id(resource_id: u16) -> Self

Gets a pattern URI that matches any given candidate URI with a specific resource ID.

pub fn authority_name(&self) -> &str

Gets the authority name part from this uProtocol URI.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("my-vehicle", 0x10101234, 0x01, 0x9a10).unwrap();
assert_eq!(uri.authority_name(), "my-vehicle");
pub fn uentity_type_id(&self) -> u16

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("my-vehicle", 0x10101234, 0x01, 0x9a10).unwrap();
assert_eq!(uri.uentity_type_id(), 0x1234);
pub fn uentity_instance_id(&self) -> u16

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("my-vehicle", 0x10101234, 0x01, 0x9a10).unwrap();
assert_eq!(uri.uentity_instance_id(), 0x1010);
pub fn uentity_major_version(&self) -> u8

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("my-vehicle", 0x10101234, 0x01, 0x9a10).unwrap();
assert_eq!(uri.uentity_major_version(), 0x01);
pub fn resource_id(&self) -> u16

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("my-vehicle", 0x10101234, 0x01, 0x9a10).unwrap();
assert_eq!(uri.resource_id(), 0x9a10);
pub fn clone_with_resource_id(&self, resource_id: u16) -> Self

Returns a copy of this URI with the resource id replaced.

pub fn verify_authority(authority: &str) -> Result<(), UUriError>

Verifies that the given authority name complies with the UUri specification.

Arguments
  • authority - The authority name to verify.
Errors

Returns an error if the authority name is invalid.

Examples
use up_rust::UUri;

assert!(UUri::verify_authority("my.vin").is_ok());
pub fn is_remote(&self, other_uri: &UUri) -> bool

Check if an UUri is remote, by comparing authority fields. UUris with empty authority are considered to be local.

Returns

‘true’ if other_uri has a different authority than Self, false otherwise.

Examples
use std::str::FromStr;
use up_rust::UUri;

let authority_a = UUri::from_str("up://authority.a/100A/1/0").unwrap();
let authority_b = UUri::from_str("up://authority.b/200B/2/20").unwrap();
assert!(authority_a.is_remote(&authority_b));

let authority_local = UUri::from_str("up:///100A/1/0").unwrap();
assert!(!authority_local.is_remote(&authority_a));

let authority_wildcard = UUri::from_str("up://*/100A/1/0").unwrap();
assert!(!authority_wildcard.is_remote(&authority_a));
assert!(!authority_a.is_remote(&authority_wildcard));
assert!(!authority_wildcard.is_remote(&authority_wildcard));
pub fn is_remote_authority(&self, authority: &str) -> bool

Check if an authority is remote compared to the authority field of the UUri. Empty authorities are considered to be local.

Returns

‘true’ if authority is a different than Self.authority_name, false otherwise.

Examples
use std::str::FromStr;
use up_rust::UUri;

let authority_a = UUri::from_str("up://authority.a/100A/1/0").unwrap();
let authority_b = "authority.b";
assert!(authority_a.is_remote_authority(&authority_b));

let authority_local = "";
assert!(!authority_a.is_remote_authority(&authority_local));

let authority_wildcard = "*";
assert!(!authority_a.is_remote_authority(&authority_wildcard));
pub fn has_empty_authority(&self) -> bool

Checks if this UUri has an empty authority name.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("", 0x9b3a, 0x01, 0x145b).unwrap();
assert!(uuri.has_empty_authority());
pub fn has_wildcard_authority(&self) -> bool

Checks if this UUri has a wildcard authority name.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("*", 0x9b3a, 0x01, 0x145b).unwrap();
assert!(uuri.has_wildcard_authority());
pub fn has_wildcard_entity_instance(&self) -> bool

Checks if this UUri has an entity identifier matching any instance.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("vin", 0xFFFF_0123, 0x01, 0x145b).unwrap();
assert!(uuri.has_wildcard_entity_instance());
pub fn has_wildcard_entity_type(&self) -> bool

Checks if this UUri has an entity identifier matching any type.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("vin", 0x00C0_FFFF, 0x01, 0x145b).unwrap();
assert!(uuri.has_wildcard_entity_type());
pub fn has_wildcard_version(&self) -> bool

Checks if this UUri has a wildcard major version.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("vin", 0x9b3a, 0xFF, 0x145b).unwrap();
assert!(uuri.has_wildcard_version());
pub fn has_wildcard_resource_id(&self) -> bool

Checks if this UUri has a wildcard entity identifier.

Examples
use up_rust::UUri;

let uuri = UUri::try_from_parts("vin", 0x9b3a, 0x01, 0xFFFF).unwrap();
assert!(uuri.has_wildcard_resource_id());
pub fn verify_no_wildcards(&self) -> Result<(), UUriError>

Verifies that this UUri does not contain any wildcards.

Errors

Returns an error if any of this UUri’s properties contain a wildcard value.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("vin.vehicles", 0x0000_2310, 0x03, 0xa000).unwrap();
assert!(uri.verify_no_wildcards().is_ok());
pub fn is_rpc_method(&self) -> bool

Checks if this UUri refers to a service method.

Returns true if 0 < resource ID < 0x8000.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x7FFF).unwrap();
assert!(uri.is_rpc_method());
pub fn verify_rpc_method(&self) -> Result<(), UUriError>

Verifies that this UUri refers to a service method.

Errors

Returns an error if Self::is_rpc_method fails or the UUri contains any wildcards.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x8000).unwrap();
assert!(uri.verify_rpc_method().is_err());

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x0000).unwrap();
assert!(uri.verify_rpc_method().is_err());
pub fn is_notification_destination(&self) -> bool

Checks if this UUri represents a destination for a Notification.

Returns true if resource ID is 0.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x0000).unwrap();
assert!(uri.is_notification_destination());
pub fn is_rpc_response(&self) -> bool

Checks if this UUri represents an RPC response address.

Returns true if resource ID is 0.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x0000).unwrap();
assert!(uri.is_rpc_response());
pub fn verify_rpc_response(&self) -> Result<(), UUriError>

Verifies that this UUri represents an RPC response address.

Errors

Returns an error if Self::is_rpc_response fails or the UUri contains any wildcards.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x4001).unwrap();
assert!(uri.verify_rpc_response().is_err());
pub fn is_event(&self) -> bool

Checks if this UUri can be used as the source of an event.

Returns true if resource ID >= 0x8000.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x8000).unwrap();
assert!(uri.is_event());
pub fn verify_event(&self) -> Result<(), UUriError>

Verifies that this UUri can be used as the source of an event.

Errors

Returns an error if Self::is_event fails or the UUri contains any wildcards.

Examples
use up_rust::UUri;

let uri = UUri::try_from_parts("", 0xabcd, 0x01, 0x7FFF).unwrap();
assert!(uri.verify_event().is_err());
pub fn matches(&self, candidate: &UUri) -> bool

Checks if a given candidate URI matches a pattern.

Returns

true if the candiadate matches the pattern represented by this UUri.

Examples
use up_rust::UUri;

let pattern = UUri::try_from("//vin/A14F/3/FFFF").unwrap();
let candidate = UUri::try_from("//vin/A14F/3/B1D4").unwrap();
assert!(pattern.matches(&candidate));