Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct UVecRxLease

pub struct UVecRxLease { /* private fields */ }
In-memory receive lease for tests and examples that need receive-lease shape.

Implementations

Source

impl UVecRxLease

pub fn new( metadata: UFrameMetadata, payload: Option<Vec<u8>>, ) -> Result<Self, UStatus>

Creates an in-memory receive lease after validation.

Errors

Returns an error if metadata or payload presence is invalid.

pub fn new_unchecked(metadata: UFrameMetadata, payload: Option<Vec<u8>>) -> Self

Creates an in-memory receive lease without validation.

pub fn into_parts(self) -> (UFrameMetadata, Option<Vec<u8>>)

Consumes the lease and returns metadata plus optional payload bytes.