pub struct UVecTxBuffer { /* private fields */ }Expand description
Owned buffer useful for tests, examples, and adapters that emulate a transmit loan.
Implementations
Sourceimpl UVecTxBuffer
impl UVecTxBuffer
Sourcepub fn new(metadata: UFrameMetadata, payload_len: usize) -> Self
pub fn new(metadata: UFrameMetadata, payload_len: usize) -> Self
Creates an owned transmit buffer with payload_len zero-initialized bytes.
Sourcepub fn with_alignment(
metadata: UFrameMetadata,
payload_len: usize,
alignment: usize,
) -> Result<Self, UStatus>
pub fn with_alignment( metadata: UFrameMetadata, payload_len: usize, alignment: usize, ) -> Result<Self, UStatus>
Creates an owned transmit buffer whose visible payload starts at alignment.
Errors
Returns an error if the requested alignment is invalid or allocation size overflows.
Sourcepub fn into_rx_lease(self) -> UVecRxLease
pub fn into_rx_lease(self) -> UVecRxLease
Converts the buffer into an in-memory receive lease, consuming the emulated loan.