Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct UVecUninitTxBuffer

pub struct UVecUninitTxBuffer { /* private fields */ }
Owned uninitialized buffer useful for tests and examples.

Implementations

Source

impl UVecUninitTxBuffer

pub fn new(metadata: UFrameMetadata, payload_len: usize) -> Self

Creates an owned uninitialized transmit buffer.

pub fn with_alignment( metadata: UFrameMetadata, payload_len: usize, alignment: usize, ) -> Result<Self, UStatus>

Creates an owned uninitialized transmit buffer whose visible payload starts at alignment.

Errors

Returns an error if the requested alignment is invalid or allocation size overflows.