pub trait UZeroCopyUninitTransportImpl: UZeroCopyTransportImpl {
type UninitTx: UUninitTxBuffer<Initialized = Self::Tx> + Send;
// Required method
fn loan_validated_uninit_tx<'life0, 'async_trait>(
&'life0 self,
spec: UTxLoanSpec,
) -> Pin<Box<dyn Future<Output = Result<Self::UninitTx, UStatus>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Role: implemented by transports that can lend uninitialized storage — see the trait map.
Implementation boundary for transports that can expose uninitialized TX payload storage.
Required Associated Types
Sourcetype UninitTx: UUninitTxBuffer<Initialized = Self::Tx> + Send
type UninitTx: UUninitTxBuffer<Initialized = Self::Tx> + Send
Transport-specific uninitialized transmit loan type.
Required Methods
Sourcefn loan_validated_uninit_tx<'life0, 'async_trait>(
&'life0 self,
spec: UTxLoanSpec,
) -> Pin<Box<dyn Future<Output = Result<Self::UninitTx, UStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn loan_validated_uninit_tx<'life0, 'async_trait>(
&'life0 self,
spec: UTxLoanSpec,
) -> Pin<Box<dyn Future<Output = Result<Self::UninitTx, UStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Reserves uninitialized transmit storage for a validated frame loan spec.