#[repr(C)]pub enum UPayloadFormat {
Unspecified = 0,
ProtobufWrappedInAny = 1,
Protobuf = 2,
Json = 3,
Someip = 4,
SomeipTlv = 5,
Raw = 6,
Text = 7,
Shm = 8,
}Expand description
Payload serialization formats defined by the uProtocol specification.
Variants
Unspecified = 0
No format specified; receivers must not assume a serialization.
ProtobufWrappedInAny = 1
Protobuf message wrapped in google.protobuf.Any.
Protobuf = 2
Protobuf message bytes.
Json = 3
JSON text.
Someip = 4
SOME/IP serialized payload.
SomeipTlv = 5
SOME/IP TLV serialized payload.
Raw = 6
Raw application-defined bytes.
Text = 7
UTF-8 text.
Shm = 8
Shared-memory reference payload.
Implementations
Sourceimpl UPayloadFormat
impl UPayloadFormat
Sourcepub fn as_i32(&self) -> i32
pub fn as_i32(&self) -> i32
Returns the integer value of the payload format as defined in the protobuf enum.
Sourcepub fn try_from_i32(value: i32) -> Result<UPayloadFormat, SerializationError>
pub fn try_from_i32(value: i32) -> Result<UPayloadFormat, SerializationError>
Sourceimpl UPayloadFormat
impl UPayloadFormat
Sourcepub fn from_media_type(media_type_string: &str) -> Result<Self, UPayloadError>
pub fn from_media_type(media_type_string: &str) -> Result<Self, UPayloadError>
Gets the payload format that corresponds to a given media type.
Errors
Returns an error if the given string is not a valid media type string or is unsupported by uProtocol.
Examples
use up_rust::UPayloadFormat;
let parse_attempt = UPayloadFormat::from_media_type("application/json; charset=utf-8");
assert!(parse_attempt.is_ok_and(|f| f == UPayloadFormat::Json));
let parse_attempt = UPayloadFormat::from_media_type("application/unsupported");
assert!(parse_attempt.is_err());Sourcepub fn to_media_type(self) -> Option<String>
pub fn to_media_type(self) -> Option<String>
Gets the media type corresponding to this payload format.
Returns
None if the payload format is UPayloadFormat::Unspecified.
Examples
use up_rust::UPayloadFormat;
assert_eq!(UPayloadFormat::Json.to_media_type().unwrap(), "application/json");
assert!(UPayloadFormat::Unspecified.to_media_type().is_none());Trait Implementations
Sourceimpl Clone for UPayloadFormat
impl Clone for UPayloadFormat
Sourcefn clone(&self) -> UPayloadFormat
fn clone(&self) -> UPayloadFormat
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UPayloadFormat
impl Debug for UPayloadFormat
Sourceimpl Hash for UPayloadFormat
impl Hash for UPayloadFormat
Sourceimpl PartialEq for UPayloadFormat
impl PartialEq for UPayloadFormat
impl Copy for UPayloadFormat
impl Eq for UPayloadFormat
impl StructuralPartialEq for UPayloadFormat