pub struct LoanedPayloadUninitMut<'a> { /* private fields */ }Expand description
Mutable uninitialized payload bytes with explicit transport-loan provenance.
Implementations
Sourceimpl<'a> LoanedPayloadUninitMut<'a>
impl<'a> LoanedPayloadUninitMut<'a>
Sourcepub unsafe fn new_unchecked(
bytes: &'a mut [MaybeUninit<u8>],
provenance: PayloadLoanProvenance,
) -> Self
pub unsafe fn new_unchecked( bytes: &'a mut [MaybeUninit<u8>], provenance: PayloadLoanProvenance, ) -> Self
Creates a mutable uninitialized loaned payload view from transport-owned storage.
Safety
bytes must be a valid mutable uninitialized byte slice for 'a, with no
other active access path, and must be the exact visible application
payload range for the loan described by provenance.
Sourcepub fn provenance(&self) -> PayloadLoanProvenance
pub fn provenance(&self) -> PayloadLoanProvenance
Returns where this loan’s storage came from.