#[repr(C)]pub struct UUID { /* private fields */ }Expand description
A uProtocol UUIDv7 message identifier (RFC 9562 layout).
Implementations
Sourceimpl UUID
impl UUID
Sourcepub fn from_bytes(bytes: &[u8; 16]) -> Result<Self, UuidConversionError>
pub fn from_bytes(bytes: &[u8; 16]) -> Result<Self, UuidConversionError>
Sourcepub fn from_u64_pair(msb: u64, lsb: u64) -> Result<Self, UuidConversionError>
pub fn from_u64_pair(msb: u64, lsb: u64) -> Result<Self, UuidConversionError>
Sourcepub fn as_u64_pair(&self) -> (u64, u64)
pub fn as_u64_pair(&self) -> (u64, u64)
Gets this UUID as a pair of 64 bit integers.
Returns
A tuple of the most significant and least significant 8 bytes,
i.e. the inverse of UUID::from_u64_pair.
Sourcepub fn build() -> UUID
pub fn build() -> UUID
Creates a new UUID that can be used for uProtocol messages.
Panics
if the system clock is set to an instant before the UNIX Epoch.
Examples
use std::time::SystemTime;
use up_rust::UUID;
let uuid = UUID::build();
assert!(uuid.time() <= SystemTime::now()
.duration_since(SystemTime::UNIX_EPOCH)
.expect("current system time is set to a point in time before UNIX Epoch")
.as_millis() as u64);Sourcepub fn to_hyphenated_string(&self) -> String
pub fn to_hyphenated_string(&self) -> String
Serializes this UUID to a hyphenated string as defined by RFC 4122, Section 3 using lower case characters.
Examples
use up_rust::UUID;
// timestamp = 1, ver = 0b0111
let msb = 0x0000000000017000_u64;
// variant = 0b10, random = 0x0010101010101a1a
let lsb = 0x8010101010101a1a_u64;
let uuid = UUID::from_u64_pair(msb, lsb).unwrap();
assert_eq!(uuid.to_hyphenated_string(), "00000000-0001-7000-8010-101010101a1a");Sourcepub fn time(&self) -> u64
pub fn time(&self) -> u64
Returns the point in time that this UUID has been created at.
Returns
The number of milliseconds since UNIX EPOCH.
Examples
use up_rust::UUID;
// timestamp = 0x018D548EA8E0 (Monday, 29 January 2024, 9:30:52 AM GMT)
// ver = 0b0111
let msb = 0x018D548EA8E07000u64;
// variant = 0b10
let lsb = 0x8000000000000000u64;
let creation_time = UUID::from_u64_pair(msb, lsb).unwrap().time();
assert_eq!(creation_time, 0x018D548EA8E0_u64);Sourcepub fn get_time(&self) -> u64
👎Deprecated since 0.11.0: renamed to time
pub fn get_time(&self) -> u64
timeDeprecated alias for Self::time.