pub struct UVecUninitTxBuffer { /* private fields */ }Expand description
Owned uninitialized buffer useful for tests and examples.
Implementations
Sourceimpl UVecUninitTxBuffer
impl UVecUninitTxBuffer
Sourcepub fn new(metadata: UFrameMetadata, payload_len: usize) -> Self
pub fn new(metadata: UFrameMetadata, payload_len: usize) -> Self
Creates an owned uninitialized transmit buffer.
Sourcepub fn with_alignment(
metadata: UFrameMetadata,
payload_len: usize,
alignment: usize,
) -> Result<Self, UStatus>
pub fn with_alignment( metadata: UFrameMetadata, payload_len: usize, alignment: usize, ) -> Result<Self, UStatus>
Creates an owned uninitialized transmit buffer whose visible payload starts at alignment.
Errors
Returns an error if the requested alignment is invalid or allocation size overflows.